@@ -130,7 +130,7 @@ class LocalRepository(object):
         """Set the protection mark in a container or image tag"""
         try:
             # touch create version file
-            open(directory + "/PROTECT", 'w').close()
+            open(directory + "/PROTECT", 'w', encoding='utf-8').close()
             return True
         except (IOError, OSError):
             return False
@@ -178,7 +178,8 @@ class LocalRepository(object):
             container_dir = self.containersdir + '/' + fname
             if os.path.isdir(container_dir):
                 try:
-                    filep = open(container_dir + "/imagerepo.name", 'r')
+                    filep = open(container_dir + "/imagerepo.name", 'r',
+                                 encoding='utf-8')
                 except (IOError, OSError):
                     reponame = ""
                 else:
@@ -292,7 +293,8 @@ class LocalRepository(object):
             return ""
         try:
             os.makedirs(container_dir + "/ROOT")
-            out_imagerepo = open(container_dir + "/imagerepo.name", 'w')
+            out_imagerepo = open(container_dir + "/imagerepo.name", 'w',
+                                 encoding='utf-8')
         except (IOError, OSError):
             return None
         else:
@@ -458,7 +460,7 @@ class LocalRepository(object):
             if not os.path.exists(directory):
                 os.makedirs(directory)
             self.cur_tagdir = directory
-            out_tag = open(directory + "/TAG", 'w')
+            out_tag = open(directory + "/TAG", 'w', encoding='utf-8')
         except (IOError, OSError):
             return False
         else:
@@ -490,7 +492,7 @@ class LocalRepository(object):
                     return False
         try:
             # Create version file
-            open(directory + "/" + version, 'a').close()
+            open(directory + "/" + version, 'a', encoding='utf-8').close()
         except (IOError, OSError):
             return False
         return True
@@ -580,7 +582,7 @@ class LocalRepository(object):
             out_filename = self.cur_tagdir + "/" + filename
         outfile = None
         try:
-            outfile = open(out_filename, 'w')
+            outfile = open(out_filename, 'w', encoding='utf-8')
             json.dump(data, outfile)
         except (IOError, OSError, AttributeError, ValueError, TypeError):
             if outfile:
@@ -607,7 +609,7 @@ class LocalRepository(object):
         json_obj = None
         infile = None
         try:
-            infile = open(in_filename, 'r')
+            infile = open(in_filename, 'r', encoding='utf-8')
             json_obj = json.load(infile)
         except (IOError, OSError, AttributeError, ValueError, TypeError):
             pass
@@ -618,7 +620,7 @@ class LocalRepository(object):
     def _load_structure(self, imagetagdir):
         """Scan the repository structure of a given image tag"""
         structure = {}
-        structure["repolayers"] = dict()
+        structure["repolayers"] = {}
         if FileUtil(imagetagdir).isdir():
             for fname in os.listdir(imagetagdir):
                 f_path = imagetagdir + '/' + fname
@@ -631,7 +633,7 @@ class LocalRepository(object):
                 if len(fname) >= 64:
                     layer_id = fname.replace(".json", "").replace(".layer", "")
                     if layer_id not in structure["repolayers"]:
-                        structure["repolayers"][layer_id] = dict()
+                        structure["repolayers"][layer_id] = {}
                     if fname.endswith("json"):
                         structure["repolayers"][layer_id]["json"] = \
                             self.load_json(f_path)
